@@ -335,6 +335,7 @@ display_introduction_message (gpointer data)
 			gnome_canvas_item_new (GNOME_CANVAS_GROUP (intro),
 					       gnome_canvas_rich_text_get_type (),
 					       "text", introduction_messages[intro_i],
+						"editable", FALSE,
 					       /* FIXME */
 					       "width", 300.0,
 					       "height", 80.0,
@@ -684,6 +685,7 @@ get_description_messages (xmlNodePtr node)
 				cur = xmlNodeGetLang (paras);
 
 				tmp = strip_newlines (value);
+
 				if (!started) {
 					started = TRUE;
 					if (!cur) {
@@ -724,9 +726,11 @@ get_description_messages (xmlNodePtr node)
 				}
 				g_free (tmp);
 				xmlFree (cur);
+				xmlFree (best);
 			}
 
 			paras = paras->next;
+			xmlFree (value);
 		}
 		list = g_slist_prepend (list, best_value);
 		started = FALSE;
@@ -741,6 +745,7 @@ get_description_messages (xmlNodePtr node)
 
 	introduction_messages[i] = NULL;
 
+	g_free (best_value);
 	g_slist_free (list);
 }
 
@@ -826,6 +831,7 @@ display_version_info (GnomeCanvasGroup *group)
 			build_date_string = create_date_string (value);
 
 		bits = bits->next;
+		xmlFree (value);
 	}
 
 	xmlFreeDoc (about);
@@ -1017,7 +1023,7 @@ create_canvas (void)
 
 	href = href_item_new (root,
 			      _("Contact"),
-			      "http://mail.gnome.org/",
+			      "http://www.gnome.org/contact/",
 			      &current_x, &current_y);
 
 	/* resize */
