@@ -51,7 +51,7 @@
 
 #include "egg-spawn.h"
 
-#include "gnome-desktop-item.h"
+#include <libgnome/gnome-desktop-item.h>
 #include "gnome-desktop-i18n.h"
 
 #ifdef HAVE_STARTUP_NOTIFICATION
